==> openwebbeans-2.0.25-source-release.zip: openwebbeans-2.0.25/webbeans-impl/src/test/java/org/apache/webbeans/test/proxy/ProxyGenericsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.proxy;

import org.apache.webbeans.test.AbstractUnitTest;
import org.junit.Assert;
import org.junit.Test;

import javax.annotation.PostConstruct;
import javax.enterprise.context.ApplicationScoped;

/**
 * test whether generics in method signatures are properly proxied.
 */
public class ProxyGenericsTest extends AbstractUnitTest
{

    @Test
    public void testGenericsOnProxy()
    {
        startContainer(XBase.class, XChild.class);

        XChild x = getInstance(XChild.class);

        Assert.assertEquals(Integer.valueOf(4711), x.doit("ignore"));
    }


    public static abstract class XBase<R,V>
    {

        private boolean isBean = false;

        @PostConstruct
        public void init()
        {
            isBean = true;
        }

        protected abstract R createR();

        public R doit(V val) {
            Assert.assertTrue(isBean);
            return createR();
        }
    }

    @ApplicationScoped
    public static class XChild extends XBase<Integer, String>
    {
        @Override
        protected Integer createR() {
            return Integer.valueOf(4711);
        }
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/proxy/ProxyGenericsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.proxy;

import org.apache.webbeans.test.AbstractUnitTest;
import org.junit.Assert;
import org.junit.Test;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.ApplicationScoped;

/**
 * test whether generics in method signatures are properly proxied.
 */
public class ProxyGenericsTest extends AbstractUnitTest
{

    @Test
    public void testGenericsOnProxy()
    {
        startContainer(XBase.class, XChild.class);

        XChild x = getInstance(XChild.class);

        Assert.assertEquals(Integer.valueOf(4711), x.doit("ignore"));
    }


    public static abstract class XBase<R,V>
    {

        private boolean isBean = false;

        @PostConstruct
        public void init()
        {
            isBean = true;
        }

        protected abstract R createR();

        public R doit(V val) {
            Assert.assertTrue(isBean);
            return createR();
        }
    }

    @ApplicationScoped
    public static class XChild extends XBase<Integer, String>
    {
        @Override
        protected Integer createR() {
            return Integer.valueOf(4711);
        }
    }
}
